import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Glue::Trigger
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const onDemandJobTrigger = new aws_native.glue.Trigger("onDemandJobTrigger", {
 *     type: "ON_DEMAND",
 *     description: "DESCRIPTION_ON_DEMAND",
 *     actions: [{
 *         jobName: "prod-job2",
 *     }],
 *     name: "prod-trigger1-ondemand",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const onDemandJobTrigger = new aws_native.glue.Trigger("onDemandJobTrigger", {
 *     type: "ON_DEMAND",
 *     description: "DESCRIPTION_ON_DEMAND",
 *     actions: [{
 *         jobName: "prod-job2",
 *     }],
 *     name: "prod-trigger1-ondemand",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const scheduledJobTrigger = new aws_native.glue.Trigger("scheduledJobTrigger", {
 *     type: "SCHEDULED",
 *     description: "DESCRIPTION_SCHEDULED",
 *     schedule: "cron(0 *&#47;2 * * ? *)",
 *     actions: [
 *         {
 *             jobName: "prod-job2",
 *         },
 *         {
 *             jobName: "prod-job3",
 *             arguments: {
 *                 "--job-bookmark-option": "job-bookmark-enable",
 *             },
 *         },
 *     ],
 *     name: "prod-trigger1-scheduled",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const scheduledJobTrigger = new aws_native.glue.Trigger("scheduledJobTrigger", {
 *     type: "SCHEDULED",
 *     description: "DESCRIPTION_SCHEDULED",
 *     schedule: "cron(0 *&#47;2 * * ? *)",
 *     actions: [
 *         {
 *             jobName: "prod-job2",
 *         },
 *         {
 *             jobName: "prod-job3",
 *             arguments: {
 *                 "--job-bookmark-option": "job-bookmark-enable",
 *             },
 *         },
 *     ],
 *     name: "prod-trigger1-scheduled",
 * });
 *
 * ```
 */
export declare class Trigger extends pulumi.CustomResource {
    /**
     * Get an existing Trigger resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Trigger;
    /**
     * Returns true if the given object is an instance of Trigger.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Trigger;
    /**
     * The actions initiated by this trigger.
     */
    readonly actions: pulumi.Output<outputs.glue.TriggerAction[]>;
    /**
     * A description of this trigger.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
     */
    readonly eventBatchingCondition: pulumi.Output<outputs.glue.TriggerEventBatchingCondition | undefined>;
    /**
     * The name of the trigger.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The predicate of this trigger, which defines when it will fire.
     */
    readonly predicate: pulumi.Output<outputs.glue.TriggerPredicate | undefined>;
    /**
     * A cron expression used to specify the schedule.
     */
    readonly schedule: pulumi.Output<string | undefined>;
    /**
     * Set to true to start SCHEDULED and CONDITIONAL triggers when created. True is not supported for ON_DEMAND triggers.
     */
    readonly startOnCreation: pulumi.Output<boolean | undefined>;
    /**
     * The tags to use with this trigger.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Glue::Trigger` for more information about the expected schema for this property.
     */
    readonly tags: pulumi.Output<any | undefined>;
    /**
     * The type of trigger that this is.
     */
    readonly type: pulumi.Output<string>;
    /**
     * The name of the workflow associated with the trigger.
     */
    readonly workflowName: pulumi.Output<string | undefined>;
    /**
     * Create a Trigger resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TriggerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Trigger resource.
 */
export interface TriggerArgs {
    /**
     * The actions initiated by this trigger.
     */
    actions: pulumi.Input<pulumi.Input<inputs.glue.TriggerActionArgs>[]>;
    /**
     * A description of this trigger.
     */
    description?: pulumi.Input<string>;
    /**
     * Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
     */
    eventBatchingCondition?: pulumi.Input<inputs.glue.TriggerEventBatchingConditionArgs>;
    /**
     * The name of the trigger.
     */
    name?: pulumi.Input<string>;
    /**
     * The predicate of this trigger, which defines when it will fire.
     */
    predicate?: pulumi.Input<inputs.glue.TriggerPredicateArgs>;
    /**
     * A cron expression used to specify the schedule.
     */
    schedule?: pulumi.Input<string>;
    /**
     * Set to true to start SCHEDULED and CONDITIONAL triggers when created. True is not supported for ON_DEMAND triggers.
     */
    startOnCreation?: pulumi.Input<boolean>;
    /**
     * The tags to use with this trigger.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Glue::Trigger` for more information about the expected schema for this property.
     */
    tags?: any;
    /**
     * The type of trigger that this is.
     */
    type: pulumi.Input<string>;
    /**
     * The name of the workflow associated with the trigger.
     */
    workflowName?: pulumi.Input<string>;
}
